@@ -1,17 +1,8 @@
 import config from 'config';
 
-import {
-  TamanuApi,
-  AuthError,
-  AuthInvalidError,
-  VersionIncompatibleError,
-} from '@tamanu/api-client';
-import {
-  BadAuthenticationError,
-  FacilityAndSyncVersionIncompatibleError,
-  RemoteCallFailedError,
-} from '@tamanu/shared/errors';
-import { SERVER_TYPES } from '@tamanu/constants';
+import { TamanuApi } from '@tamanu/api-client';
+import { DEVICE_SCOPES, SERVER_TYPES } from '@tamanu/constants';
+import { ERROR_TYPE } from '@tamanu/errors';
 import { selectFacilityIds } from '@tamanu/utils/selectFacilityIds';
 import { log } from '@tamanu/shared/services/logging';
 
@@ -68,7 +59,7 @@ export class CentralServerConnection extends TamanuApi {
     try {
       return await super.fetch(endpoint, query, config);
     } catch (error) {
-      if (retryAuth && error instanceof AuthError) {
+      if (retryAuth && error.type?.startsWith(ERROR_TYPE.AUTH)) {
         await this.connect();
         return await super.fetch(endpoint, query, config);
       }
@@ -94,33 +85,13 @@ export class CentralServerConnection extends TamanuApi {
     const { email, password } = config.sync;
     log.info(`Logging in to ${this.host} as ${email}...`);
 
-    try {
-      return await this.login(email, password, {
-        backoff,
-        timeout,
-      }).then(loginData => {
-        return (this.#loginData = loginData);
-      });
-    } catch (error) {
-      if (error instanceof AuthInvalidError) {
-        const newError = new BadAuthenticationError(error.message);
-        newError.response = error.response;
-        newError.cause = error;
-        throw newError;
-      }
-
-      if (error instanceof VersionIncompatibleError) {
-        const newError = new FacilityAndSyncVersionIncompatibleError(error.message);
-        newError.response = error.response;
-        newError.cause = error;
-        throw newError;
-      }
-
-      const newError = new RemoteCallFailedError(error.message);
-      newError.response = error.response;
-      newError.cause = error;
-      throw newError;
-    }
+    return await this.login(email, password, {
+      backoff,
+      timeout,
+      scopes: [DEVICE_SCOPES.SYNC_CLIENT],
+    }).then(loginData => {
+      return (this.#loginData = loginData);
+    });
   }
 
   async loginData() {
