@@ -7,14 +7,15 @@ import { REFERENCE_DATA_TRANSLATION_PREFIX } from '@tamanu/constants';
  * @example "test.value" → "test_value"
  * @example "hello.world test" → "hello_world_test"
  */
-const formatOptionForStringId = str => str?.replace(/[\s.]/g, '_');
+const formatOptionForStringId = str => `${str}`.replace(/[\s.]/g, '_');
 
 /**
  * Returns the stringId for a reference data option.
  * @example getReferenceDataOptionStringId('question1', 'surveyScreenComponent', 'undecided') -> "refData.surveyScreenComponent.detail.question1.option.undecided"
  */
 export const getReferenceDataOptionStringId = (value, category, option) => {
-  return `${getReferenceDataStringId(value, category)}.option.${formatOptionForStringId(option)}`;
+  const baseStringId = `${getReferenceDataStringId(value, category)}.option`;
+  return `${baseStringId}.${formatOptionForStringId(option)}`;
 };
 
 /**
